@@ -144,7 +144,7 @@ class Snap(s_base.Base):
         async with await s_storm.Runtime.anit(query, self, opts=opts, user=user) as runt:
             yield runt
 
-    async def iterStormPodes(self, text, opts=None, user=None):
+    async def iterStormPodes(self, text, opts, user=None):
         '''
         Yield packed node tuples for the given storm query text.
         '''
@@ -154,7 +154,7 @@ class Snap(s_base.Base):
         dorepr = False
         dopath = False
 
-        self.core._logStormQuery(text, user)
+        self.core._logStormQuery(text, user, opts.get('mode', 'storm'))
 
         # { form: ( embedprop, ... ) }
         embeds = opts.get('embeds')
@@ -171,7 +171,7 @@ class Snap(s_base.Base):
         async for node, path in self.storm(text, opts=opts, user=user):
 
             pode = node.pack(dorepr=dorepr)
-            pode[1]['path'] = path.pack(path=dopath)
+            pode[1]['path'] = await path.pack(path=dopath)
 
             if scrubber is not None:
                 pode = scrubber.scrub(pode)
@@ -673,20 +673,27 @@ class Snap(s_base.Base):
         '''
         Sends edits to the write layer and evaluates the consequences (triggers, node object updates)
         '''
+        meta = await self.getSnapMeta()
+        saveoff, changes, nodes = await self._applyNodeEdits(edits, meta)
+        return nodes
+
+    async def saveNodeEdits(self, edits, meta):
+        saveoff, changes, nodes = await self._applyNodeEdits(edits, meta)
+        return saveoff, changes
+
+    async def _applyNodeEdits(self, edits, meta):
+
         if self.readonly:
             mesg = 'The snapshot is in read-only mode.'
             raise s_exc.IsReadOnly(mesg=mesg)
 
-        meta = await self.getSnapMeta()
-
-        todo = s_common.todo('storNodeEdits', edits, meta)
-        results = await self.core.dyncall(self.wlyr.iden, todo)
-
         wlyr = self.wlyr
         nodes = []
         callbacks = []
         actualedits = []  # List[Tuple[buid, form, changes]]
 
+        saveoff, changes, results = await wlyr._realSaveNodeEdits(edits, meta)
+
         # make a pass through the returned edits, apply the changes to our Nodes()
         # and collect up all the callbacks to fire at once at the end.  It is
         # critical to fire all callbacks after applying all Node() changes.
@@ -726,7 +733,7 @@ class Snap(s_base.Base):
                     (name, valu, oldv, stype) = parms
 
                     prop = node.form.props.get(name)
-                    if prop is None: # pragma: no cover
+                    if prop is None:  # pragma: no cover
                         logger.warning(f'applyNodeEdits got EDIT_PROP_SET for bad prop {name} on form {node.form}')
                         continue
 
@@ -742,7 +749,7 @@ class Snap(s_base.Base):
                     (name, oldv, stype) = parms
 
                     prop = node.form.props.get(name)
-                    if prop is None: # pragma: no cover
+                    if prop is None:  # pragma: no cover
                         logger.warning(f'applyNodeEdits got EDIT_PROP_DEL for bad prop {name} on form {node.form}')
                         continue
 
@@ -810,7 +817,7 @@ class Snap(s_base.Base):
                 await self.fire('prov:new', time=meta['time'], user=meta['user'], prov=providen, provstack=provstack)
             await self.fire('node:edits', edits=actualedits)
 
-        return nodes
+        return saveoff, changes, nodes
 
     async def addNode(self, name, valu, props=None):
         '''
@@ -1143,7 +1150,7 @@ class Snap(s_base.Base):
                 except asyncio.CancelledError:  # pragma: no cover  TODO:  remove once >= py 3.8 only
                     raise
 
-                except: # pragma: no cover
+                except:  # pragma: no cover
                     await self.warn(f'Failed to make n2 edge node for {n2iden}')
                     continue
 
@@ -1155,7 +1162,7 @@ class Snap(s_base.Base):
                 await self.warn(f'Invalid n2 iden {n2iden}')
                 continue
 
-            if not (isinstance(verb, str)): # pragma: no cover
+            if not (isinstance(verb, str)):  # pragma: no cover
                 await self.warn(f'Invalid edge verb {verb}')
                 continue
 
