@@ -39,6 +39,16 @@ pennretn = (9, pennhash)
 rgryretn = (11, rgryhash)
 bbufretn = (len(bbuf), bbufhash)
 
+linesbuf = b'''asdf
+
+qwer
+'''
+
+jsonsbuf = b'''
+{"foo": "bar"}
+{"baz": "faz"}
+'''
+
 class HttpPushFile(s_httpapi.StreamHandler):
 
     async def prepare(self):
@@ -218,6 +228,21 @@ class AxonTest(s_t_utils.SynTest):
         self.len(2, [item[1] async for item in axon.hashes(0) if item[1][0] == bbufhash])
         self.len(1, [item[1] async for item in axon.hashes(2) if item[1][0] == bbufhash])
 
+        # readlines / jsonlines
+        (lsize, l256) = await axon.put(linesbuf)
+        (jsize, j256) = await axon.put(jsonsbuf)
+        (bsize, b256) = await axon.put(b'\n'.join((jsonsbuf, linesbuf)))
+
+        lines = [item async for item in axon.readlines(s_common.ehex(l256))]
+        self.eq(('asdf', '', 'qwer'), lines)
+        jsons = [item async for item in axon.jsonlines(s_common.ehex(j256))]
+        self.eq(({'foo': 'bar'}, {'baz': 'faz'}), jsons)
+        jsons = []
+        with self.raises(s_exc.BadJsonText):
+            async for item in axon.jsonlines(s_common.ehex(b256)):
+                jsons.append(item)
+        self.eq(({'foo': 'bar'}, {'baz': 'faz'}), jsons)
+
     async def test_axon_base(self):
         async with self.getTestAxon() as axon:
             self.isin('axon', axon.dmon.shared)
@@ -500,7 +525,7 @@ class AxonTest(s_t_utils.SynTest):
         async with self.getTestAxon(conf=conf) as axon:
             async with axon.getLocalProxy() as proxy:
                 resp = await proxy.wget('http://vertex.link')
-                self.ne(-1, resp['mesg'].find('Can not connect to proxy 127.0.0.1:1'))
+                self.isin('Can not connect to proxy 127.0.0.1:1', resp.get('mesg', ''))
 
     async def test_axon_wput(self):
 
@@ -572,7 +597,6 @@ class AxonTest(s_t_utils.SynTest):
                 host, port = await axon.addHttpsPort(0, host='127.0.0.1')
                 url = f'https://root:root@localhost:{port}/api/v1/active'
                 resp = await axon.wget(url)
-                print(resp)
                 self.true(resp.get('ok'))
 
                 retn = await axon.put(abuf)
